@@ -16,9 +16,7 @@ corner.label<-function(label=NULL,x=-1,y=1,xoff=NA,yoff=NA,figcorner=FALSE,...)
   ypos<-ypos+y*ymar
  }
  if(!is.null(label)) {
-  if(figcorner) par(xpd=TRUE)
-  text(xpos-x*xoff,ypos-y*yoff,label,adj=c((1+x)/2,(1+y)/2),...)
-  if(figcorner) par(xpd=FALSE)
+  text(xpos-x*xoff,ypos-y*yoff,label,adj=c((1+x)/2,(1+y)/2),xpd=TRUE,...)
  }
  return(list(x=xpos,y=ypos))
 }
